/**
 * This program puts the message on the queue and reads it from the queue in Browse mode.
 * While reading from the queue it doesnt take the message from the queue. The message always remains there.
 * For this u need to open the queue with options for brwsing.
 * And then add Get Message option for browsing only.
 * Creation date: (26/05/2001 9:52:39 AM)
 * @author: Upkar Sharma
 */

import com.ibm.mq.*;

public class MQBrowse {
	private String qManager ="QM_dell_116";
	private MQQueueManager qMgr;
	
/**
 * MQBrowse constructor comment.
 */
public MQBrowse() {
	try{
			
			// Create a connection to the queue manager
			qMgr =new MQQueueManager(qManager);

			// Set up the options on the queue we wish to open...
	  		// Note. All MQSeries Options are prefixed with MQC in Java.
			
	  		int openOptions =MQC.MQOO_INPUT_AS_Q_DEF |MQC.MQOO_OUTPUT ;
			
			

			// Now specify the queue that we wish to open,and the open options.
			// Here the queue name is "default".
			MQQueue system_default_local_queue = qMgr.accessQueue("default",
							openOptions);

			// Define a simple MQSeries message, and 
	   		//write some text in UTF format..
			MQMessage hello_world =new MQMessage();
			
			hello_world.writeUTF("Hello World");

			// specify the message options...
			MQPutMessageOptions pmo =new MQPutMessageOptions();
			// accept the defaults,
			// same as MQPMO_DEFAULT constant.

   			// put the message on the queue.
	
			system_default_local_queue.put(hello_world,pmo);
			System.out.println("Message put on queue");

			system_default_local_queue.close();
				
			// Put the message for 10 seconds.View the message on the queue.			
			Thread.sleep(10000);
			
			// get the message back again...
	  			// First define a MQSeries message buffer to 
	  			//receive the message into..

	  		// Note: Open the queue for browsing option. (Important)
	  		openOptions = MQC.MQOO_BROWSE;
	  		
			MQQueue system_default_local_queue1 = qMgr.accessQueue("default",
							openOptions);
	  		
	  			
			MQMessage retrievedMessage =new MQMessage();
			
			retrievedMessage.messageId =hello_world.messageId;

			// Set the get message options..
			
			MQGetMessageOptions gmo =new MQGetMessageOptions();  // accept the defaults
									     // same as MQGMO_DEFAULT 

			// Note: This is important. Set Get message option for browsing only.
			gmo.options = MQC.MQGMO_BROWSE_FIRST;
			
			// get the message off the queue..
			
			system_default_local_queue1.get(retrievedMessage,gmo);
			System.out.println("Message retrieved from the queue");
			
			// And prove we have the message by displaying the UTF message text
			String msgText =retrievedMessage.readUTF();
			
			System.out.println("The message is:"+msgText);

			// Close the queue.
			system_default_local_queue1.close();

			// Disconnect from the queue manager.
			qMgr.disconnect();	
			
			} // End of try
			
			// If an error has occurred in the above, try to identify what went wrong.
				// Was it an MQSeries error?
				
			catch (MQException ex) {
			
				System.out.println("An MQSeries error occurred :Completion code "+
				ex.completionCode +"Reason code "+ex.reasonCode);
			}

			// Was it a Java buffer space error?
			
				catch (java.io.IOException ex) {
	
					System.out.println("An error occurred whilst writing to the message buffer: " + ex);
				}
			
			// Was it any other exception including java.lang.InterruptedException caused
			// by Thread.sleep(10000) method.
			
			catch (Exception ex) {
			
				System.out.println("An error occurred whilst writing to the message buffer:"+ex);
			} //End of catch.	

}
/**
 * Insert the method's description here.
 * Creation date: (26/05/2001 9:59:30 AM)
 * @param args java.lang.String[]
 */
public static void main(String[] args) {
	new MQBrowse();	
}
}
